@@ -98,10 +98,19 @@ sub test_dist {
     my $dist_dir = File::Spec->catdir( qw/t dist /, $case->{name} );
     my $work_dir = tempdir( 
         "CPAN-Reporter-testdist-XXXXXXXX", TMPDIR => 1, CLEANUP => 1
-    );
-    ok( dircopy($dist_dir, $work_dir),
-        "Copying $case->{name} to temporary build directory"
-    ) or diag $!;
+    ) or die "Couldn't create temp dir: $!";
+
+    # workaround badly broken F::C::R 0.34 on Windows
+    if ( File::Copy::Recursive->VERSION eq '0.34' && $^O eq 'MSWin32' ) {
+        ok( 0 == system("xcopy /q /e $dist_dir $work_dir"),
+            "Copying $case->{name} to temporary build directory (XCOPY)"
+        ) or diag $!;
+    }
+    else {
+        ok( defined( dircopy($dist_dir, $work_dir) ),
+            "Copying $case->{name} to temporary build directory"
+        ) or diag $!;
+    }
 
     my $pushd = pushd $work_dir; # dies on failure
     my $cur_dir = File::Spec->rel2abs(File::Spec->curdir());
